//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgs](index.md)/[selfWind](self-wind.md)

# selfWind

[common]\
val [selfWind](self-wind.md): [Wind](../../mahjongutils.models/-wind/index.md)?

#### Parameters

common

| | |
|---|---|
| selfWind | 自风 |
